@@ -18,7 +18,7 @@ LOG_FORMAT = ('%(levelname) -10s %(asctime)s %(name) -30s %(funcName) '
               '-35s %(lineno) -5d: %(message)s')
 LOG_LEVEL = logging.WARNING
 XSAN_CONFIG_DIR = ''
-XSAN_VOLUME_CONFIG_REGEX = r'([A-Z]+)\.cfg'
+XSAN_VOLUME_CONFIG_REGEX = r'(.+)\.cfg'
 XSAN_CONFIG_NODE_REGEX = r'Node \"(.+)\" \d+'
 CLIENT_UPDATE_DELAY = 2.0
 
@@ -68,13 +68,18 @@ def update_volume_list(xsan_config_path, xsan_config_regex, config_node_regex):
         config_file_list = os.listdir(xsan_config_path)
 
         for config_file_name in config_file_list:
+            #   We'll add the volume only if it looks like a real volume config
+            #   We consider it a volume config, if any line there matches config_node_regex
+            #   If any line matched, we change is_a_volume config to True and add a new record to DB model xsan_volume
+            is_a_volume_config = False
+
             if re.match(xsan_config_regex, config_file_name):
                 #   Save our volume
                 volume_name = os.path.splitext(config_file_name)[0]
+
                 volume = models.xsan_volume(
                     name=volume_name
                 )
-                volume.save()
 
                 if re.match(xsan_config_regex, config_file_name):
                     config_file_path = os.path.join(xsan_config_path, config_file_name)
@@ -83,12 +88,19 @@ def update_volume_list(xsan_config_path, xsan_config_regex, config_node_regex):
                     for line in config_file:
                         line_match = re.match(config_node_regex, line)
                         if line_match:
+                            if not is_a_volume_config:
+                                #   Looks like a proper config!
+                                #   So, we save the volume record safely
+                                is_a_volume_config = True
+                                volume.save()
+
                             nodeName = line_match.groups()[0]
                             lun = models.xsan_volume_lun(
                                 label=nodeName,
                                 volume=volume
                             )
                             lun.save()
+
     else:
         LOGGER.warning('We don\'t seem to be running on an MDC!')
 
